django-simple-history
=====================

.. image:: https://secure.travis-ci.org/treyhunner/django-simple-history.png?branch=master
   :target: http://travis-ci.org/treyhunner/django-simple-history
   :alt: Build Status

.. image:: https://img.shields.io/codecov/c/github/treyhunner/django-simple-history/master.svg
   :target: http://codecov.io/github/treyhunner/django-simple-history?branch=master
   :alt: Test Coverage

.. image:: https://img.shields.io/pypi/v/django-simple-history.svg
   :target: https://pypi.python.org/pypi/django-simple-history
   :alt: PyPI Version

.. image:: https://landscape.io/github/treyhunner/django-simple-history/master/landscape.png
   :target: https://landscape.io/github/treyhunner/django-simple-history/master
   :alt: Code Health


django-simple-history stores Django model state on every create/update/delete.

This app supports the following combinations of Django and Python:

==========  ==================
  Django      Python
==========  ==================
1.11        2.7, 3.4, 3.5, 3.6
2.0         3.4, 3.5, 3.6
2.1         3.5, 3.6
==========  ==================

Getting Help
------------

Documentation is available at https://django-simple-history.readthedocs.io/

Issue tracker is at https://github.com/treyhunner/django-simple-history/issues

Pull requests are welcome.  Read the CONTRIBUTING file for tips on
submitting a pull request.

.. _PyPI: https://pypi.python.org/pypi/django-email-log/
